changeset 347:d2ce15eed8c1 prerelease

Sets date on the board to ensure that heavy projects are recompiled
author Giulio Moro <giuliomoro@yahoo.it>
date Tue, 07 Jun 2016 17:29:54 +0100
parents 0e1e0dfe24c5
children db1e024858b0
files scripts/build_pd_heavy.sh
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/build_pd_heavy.sh	Tue Jun 07 03:40:01 2016 +0100
+++ b/scripts/build_pd_heavy.sh	Tue Jun 07 17:29:54 2016 +0100
@@ -169,8 +169,8 @@
     # UPDATED_FILES=`rsync -naic --log-format="%f" "$projectpath" "$BBB_BELA_HOME"/source | grep -v "\.$"`
     # echo "UPDATEDFILES : $UPDATED_FILES"
     # exit 2
-    # remove old executable and heavy context .o/.d files
-    ssh $BBB_ADDRESS "rm -rf "$BBB_PROJECT_FOLDER/$BBB_PROJECT_NAME;
+    # sets the date, remove old executable and heavy context .o/.d files
+    ssh $BBB_ADDRESS "date -s '`date`' > /dev/null; rm -rf "$BBB_PROJECT_FOLDER/$BBB_PROJECT_NAME;
     SCREEN_NAME=BeagleRT
     # Make new BeagleRT execut/able and run
     # It does not look very nice that we type the same things over and over